@@ -89,15 +89,13 @@ typedef long ptrdiff_t;
 # include <sys/socket.h>
 #endif
 
-#ifdef LIBMCRYPT24
-# define USE_MCRYPT
-#endif
-
 #ifndef HAVE_UINT
 typedef unsigned int uint;
 typedef signed int sint;
 #endif
 
+#define SIZEOF_UNSIGNED_LONG_INT SIZEOF_UNSIGNED_LONG
+
 #if SIZEOF_UNSIGNED_LONG == 8
 # define HAVE_UINT64
 /* only used native uint64 in 64 bit machines */
