@@ -125,7 +125,7 @@ typedef enum gnutls_openpgp_key_status { GNUTLS_OPENPGP_KEY,
 typedef enum gnutls_close_request { GNUTLS_SHUT_RDWR=0, GNUTLS_SHUT_WR=1 } gnutls_close_request;
 
 typedef enum HandshakeState { STATE0=0, STATE1, STATE2, STATE3, STATE4, STATE5,
-	STATE6, STATE7, STATE8, STATE9, STATE10, STATE11, STATE20=20, STATE21,
+	STATE6, STATE7, STATE8, STATE9, STATE20=20, STATE21,
 	STATE30=30, STATE31, STATE50=50, STATE60=60, STATE61 } HandshakeState;
 
 typedef enum HandshakeType { GNUTLS_HELLO_REQUEST, GNUTLS_CLIENT_HELLO, GNUTLS_SERVER_HELLO,
