@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 2001 Nikos Mavroyanopoulos
+ * Copyright (C) 2001 Nikos Mavroyanopoulos
  *
  * This file is part of GNUTLS.
  *
@@ -159,7 +159,7 @@ gnutls_datum tmpdata;
 
 	if ( cert != NULL)
 	   if ( cert->keyUsage != 0)
-		if ( !(cert->keyUsage & GNUTLS_X509KEY_DIGITAL_SIGNATURE)) {
+		if ( !(cert->keyUsage & KEY_DIGITAL_SIGNATURE)) {
 			gnutls_assert();
 			return GNUTLS_E_KEY_USAGE_VIOLATION;
 		}
@@ -206,14 +206,14 @@ int _gnutls_pkcs1_rsa_verify_sig( gnutls_cert *cert, const gnutls_datum *hash_co
 							       * if it is initialized
 							       */
 		gnutls_assert();
-		return GNUTLS_E_X509_CERTIFICATE_ERROR;
+		return GNUTLS_E_CERTIFICATE_ERROR;
 	}
 
 	/* If the certificate supports signing continue.
 	 */
 	if ( cert != NULL)
 	   if ( cert->keyUsage != 0)
-		if ( !(cert->keyUsage & GNUTLS_X509KEY_DIGITAL_SIGNATURE)) {
+		if ( !(cert->keyUsage & KEY_DIGITAL_SIGNATURE)) {
 			gnutls_assert();
 			return GNUTLS_E_KEY_USAGE_VIOLATION;
 		}
